@@ -6,6 +6,7 @@ use App::gh::Utils;
 use URI;
 use Text::Wrap;
 use HTML::Strip;
+use IO::Pager;
 
 =head1 NAME
 
@@ -24,11 +25,6 @@ sub run {
     eval { require XML::Atom::Feed; };
     die 'Please install XML::Atom::Feed to enable this command.' if $@;
 
-    local $STDOUT;
-    eval { require IO::Pager; };
-    unless( $@ ) {
-        $STDOUT = new IO::Pager       *STDOUT;
-    }
 
     my $user  = App::gh->config->github_id();
     my $token = App::gh->config->github_token();
@@ -37,6 +33,7 @@ sub run {
         or die XML::Atom::Feed->error;
 
 
+    local $STDOUT = new IO::Pager       *STDOUT;
     $Text::Wrap::columns = 90;
 
     for my $entry ( $feed->entries ) {
